@@ -138,6 +138,9 @@ artixpkg_repo_move() {
                         update_yaml_move "${SRC}" "${DEST}"
 
                         team=$(detect_team)
+                        if [[ -z "$team" ]]; then
+                            team=$(team_from_yaml)
+                        fi
                         update_yaml_team "${team}"
 
                         if [[ -z ${AGENT} ]]; then
